<?php

declare(strict_types=1);
require_once \dirname(__DIR__, 3).'/admin/includes/admininclude.php';
$oAccount->permission('PLUGIN_ADMIN_VIEW', true, true);

require_once __DIR__.'/../src/warmup.php';

if ($P->isXHR()) {
  $params   = array_merge($_GET, $_POST);
  $response = ['status' => 'ok', 'message' => '', 'data' => ''];
  switch ($params['action']) {
    case 'assignCountry':
      $stmt = $P->getPDO()->prepare('INSERT INTO xplugin_cin_autocurrency_countries_currencies
        (country_code, kWaehrung)
        VALUES(:country_code, :kwaehrung)');
      $stmt->execute([
        ':country_code' => $params['country_code'],
        ':kwaehrung'    => $params['kWaehrung']
      ]);
      $response['message'] = 'Zuordnung wurde gespeichert';

      $stmt = $P->getPDO()->prepare('SELECT * FROM xplugin_cin_autocurrency_countries_currencies');
      $stmt->execute();
      $response['data'] = $stmt->fetchAll(PDO::FETCH_ASSOC);

      break;

    case 'removeCountry':
      $stmt = $P->getPDO()->prepare('DELETE FROM xplugin_cin_autocurrency_countries_currencies
        WHERE country_code = :country_code
        AND kWaehrung = :kwaehrung
      ');
      $stmt->execute([
        ':country_code' => $params['country_code'],
        ':kwaehrung'    => $params['kWaehrung']
      ]);
      $response['message'] = 'Zurodnung wurde entfernt';
      $stmt                = $P->getPDO()->prepare('SELECT * FROM xplugin_cin_autocurrency_countries_currencies');
      $stmt->execute();

      $response['data'] = $stmt->fetchAll(PDO::FETCH_ASSOC);

      break;

    case 'assignRegion':
      $stmt = $P->getPDO()->prepare('UPDATE xplugin_cin_autocurrency_regions_currencies SET kWaehrung = :kwaehrung WHERE region_code = :region_code');
      $stmt->execute([
        ':region_code' => $params['region_code'],
        ':kwaehrung'   => $params['kWaehrung']
      ]);
      $response['message'] = 'Währung zugeordnet';
      $stmt                = $P->getPDO()->prepare('SELECT * FROM xplugin_cin_autocurrency_regions_currencies');
      $stmt->execute();

      $response['data'] = $stmt->fetchAll(PDO::FETCH_ASSOC);

      break;
    case 'stats':
      $stmt = $P->getPDO()->prepare('SELECT COUNT(ip_from) AS cnt FROM xplugin_cin_ip2location_db1');
      $stmt->execute();
      $response['ipv4count'] = $stmt->fetchColumn();

      $stmt = $P->getPDO()->prepare('SELECT COUNT(ip_from) AS cnt FROM xplugin_cin_ip2location_db1_ipv6');
      $stmt->execute();
      $response['ipv6count'] = $stmt->fetchColumn();

      $response['lastupdate'] = date('Y.m.d H:i:s', filemtime(__DIR__.'/../src/datasourceupdated'));

      break;

    case 'updateInternals':
      $response = ['status' => 'ok', 'message' => '', 'data' => []];

      $stmt = $P->getPDO()->prepare('SELECT DISTINCT country_code, country_name
        FROM xplugin_cin_ip2location_db1
        WHERE country_code != ?');
      $stmt->execute(['-']);
      $allCountries = [];
      foreach ($stmt->fetchAll() as $country) {
        $allCountries[$country->country_code] = [
          'country_code' => $country->country_code,
          'country_name' => $country->country_name
        ];
      }

      $allCountries['-'] = [
        'country_code' => '-',
        'country_name' => 'localhost'
      ];

      $stmt = $P->getPDO()->prepare('SELECT * FROM twaehrung ORDER BY cISO');
      $stmt->execute();
      $allCurrencies = [];
      foreach ($stmt->fetchAll() as $currency) {
        $allCurrencies[$currency->kWaehrung] = $currency;
      }

      $stmt = $P->getPDO()->prepare('SELECT * FROM xplugin_cin_autocurrency_countries_currencies');
      $stmt->execute();
      $assignments = $stmt->fetchAll(PDO::FETCH_ASSOC);

      $response['data']['allCountries']  = $allCountries;
      $response['data']['allCurrencies'] = $allCurrencies;
      $response['data']['assignments']   = $assignments;

      break;

    default:
      $response['status']  = 'error';
      $response['message'] = "action '{$params['action']} is not defined'";
  }
  header('Content-Type: application/json');
  exit(json_encode($response, 512));
}
$output = true;
if (file_exists(__DIR__.'/../src/datasourceupdated')) {
  unlink(__DIR__.'/../src/datasourceupdated');
}
require_once __DIR__.'/../src/updatedatasource.php';
